"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const cli_ux_1 = require("cli-ux");
const nock = require("nock");
const command_1 = require("./command");
class Command extends command_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () { });
    }
}
jest.mock('netrc-parser', () => {
    return class {
        constructor() {
            this.machines = { 'api.heroku.com': { password: 'mypass' } };
        }
    };
});
let env = process.env;
let api;
beforeEach(() => {
    process.env = {};
    api = nock('https://api.heroku.com');
});
afterEach(() => {
    process.env = env;
    api.done();
});
test('makes an HTTP request', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
    api = nock('https://api.heroku.com', {
        reqheaders: { authorization: 'Bearer mypass' },
    });
    api.get('/apps').reply(200, [{ name: 'myapp' }]);
    const { cmd } = yield Command.mock();
    const { body } = yield cmd.heroku.get('/apps');
    expect(body).toEqual([{ name: 'myapp' }]);
}));
describe('with HEROKU_HEADERS', () => {
    test('makes an HTTP request with HEROKU_HEADERS', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        process.env.HEROKU_HEADERS = `{"x-foo": "bar"}`;
        api = nock('https://api.heroku.com', {
            reqheaders: { 'x-foo': 'bar' },
        });
        api.get('/apps').reply(200, [{ name: 'myapp' }]);
        const { cmd } = yield Command.mock();
        const { body } = yield cmd.heroku.get('/apps');
        expect(body).toEqual([{ name: 'myapp' }]);
    }));
});
test('2fa no preauth', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
    api = nock('https://api.heroku.com');
    api.get('/apps').reply(403, { id: 'two_factor' });
    api.get('/apps').matchHeader('heroku-two-factor-code', '123456').reply(200, [{ name: 'myapp' }]);
    const { cmd } = yield Command.mock();
    cli_ux_1.default.prompt = jest.fn().mockReturnValueOnce(Promise.resolve('123456'));
    const { body } = yield cmd.heroku.get('/apps');
    expect(body).toEqual([{ name: 'myapp' }]);
}));
test('2fa preauth', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
    api = nock('https://api.heroku.com');
    api.get('/apps/myapp').reply(403, { id: 'two_factor', app: { name: 'myapp' } });
    api.put('/apps/myapp/pre-authorizations').matchHeader('heroku-two-factor-code', '123456').reply(200, {});
    api.get('/apps/myapp').reply(200, { name: 'myapp' });
    api.get('/apps/anotherapp').reply(200, { name: 'anotherapp' });
    api.get('/apps/myapp/config').reply(200, { foo: 'bar' });
    api.get('/apps/myapp/dynos').reply(200, { web: 1 });
    const { cmd } = yield Command.mock();
    cli_ux_1.default.prompt = jest.fn().mockReturnValueOnce(Promise.resolve('123456'));
    const info = cmd.heroku.get('/apps/myapp');
    const anotherapp = cmd.heroku.get('/apps/anotherapp');
    const config = cmd.heroku.get('/apps/myapp/config');
    const dynos = cmd.heroku.get('/apps/myapp/dynos');
    expect((yield info).body).toEqual({ name: 'myapp' });
    expect((yield anotherapp).body).toEqual({ name: 'anotherapp' });
    expect((yield config).body).toEqual({ foo: 'bar' });
    expect((yield dynos).body).toEqual({ web: 1 });
}));
