"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@cli-engine/command");
const cli_ux_1 = require("cli-ux");
const flags = require("./org");
let env = process.env;
beforeEach(() => {
    process.env = {};
});
afterEach(() => {
    process.env = env;
});
describe('required', () => {
    class OrgCommand extends command_1.Command {
        run() {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                cli_ux_1.cli.log(this.flags.org);
            });
        }
    }
    OrgCommand.flags = { org: flags.org({ required: true }) };
    test('has an org', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { stdout } = yield OrgCommand.mock(['--org', 'myorg']);
        expect(stdout).toEqual('myorg\n');
    }));
    test('errors with no org', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        expect.assertions(1);
        try {
            yield OrgCommand.mock();
        }
        catch (err) {
            expect(err.message).toContain('Missing required flag:\n -o, --org');
        }
    }));
});
describe('optional', () => {
    class OrgCommand extends command_1.Command {
        run() {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                cli_ux_1.cli.log(this.flags.org);
            });
        }
    }
    OrgCommand.flags = { org: flags.org() };
    test('--org', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield OrgCommand.mock(['--org', 'myorg']);
        expect(cli_ux_1.cli.stdout.output).toEqual('myorg\n');
    }));
    test('-o', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield OrgCommand.mock(['-o', 'myorg']);
        expect(cli_ux_1.cli.stdout.output).toEqual('myorg\n');
    }));
    test('reads HEROKU_ORGANIZATION', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        class OrgCommand extends command_1.Command {
            run() {
                return tslib_1.__awaiter(this, void 0, void 0, function* () {
                    cli_ux_1.cli.log(this.flags.org);
                });
            }
        }
        OrgCommand.flags = { org: flags.org() };
        process.env.HEROKU_ORGANIZATION = 'myorg';
        yield OrgCommand.mock();
        expect(cli_ux_1.cli.stdout.output).toEqual('myorg\n');
    }));
    test('is hidden by default', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        expect(flags.org().hidden).toBe(true);
    }));
    test('does not error when org is not specified', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield OrgCommand.mock();
    }));
});
