"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@cli-engine/command");
const flags = require("./pipeline");
describe('required', () => {
    class PipelineCommand extends command_1.Command {
        run() {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                this.pipeline = this.flags.pipeline;
            });
        }
    }
    PipelineCommand.flags = { pipeline: flags.pipeline({ required: true }) };
    test('has a pipeline', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { cmd } = yield PipelineCommand.mock(['--pipeline', 'mypipeline']);
        expect(cmd.pipeline).toEqual('mypipeline');
    }));
    test('errors with no pipeline', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        expect.assertions(1);
        try {
            yield PipelineCommand.mock();
        }
        catch (err) {
            expect(err.message).toContain('Missing required flag:\n -p, --pipeline PIPELINE');
        }
    }));
});
describe('optional', () => {
    class PipelineCommand extends command_1.Command {
        run() {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                this.pipeline = this.flags.pipeline;
            });
        }
    }
    PipelineCommand.flags = { pipeline: flags.pipeline() };
    test('--pipeline', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { cmd } = yield PipelineCommand.mock(['--pipeline', 'mypipeline']);
        expect(cmd.pipeline).toEqual('mypipeline');
    }));
    test('-p', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { cmd } = yield PipelineCommand.mock(['-p', 'mypipeline']);
        expect(cmd.pipeline).toEqual('mypipeline');
    }));
    test('is not hidden by default', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        expect(flags.pipeline().hidden).toBeFalsy();
    }));
    test('does not error when pipeline is not specified', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield PipelineCommand.mock();
    }));
});
