"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@cli-engine/command");
const flags = require(".");
let env = process.env;
let teamfn;
beforeEach(() => {
    process.env = {};
    teamfn = jest.fn();
});
afterEach(() => {
    process.env = env;
});
describe('required', () => {
    class TeamCommand extends command_1.Command {
        run() {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                teamfn(this.flags.team);
            });
        }
    }
    TeamCommand.flags = { team: flags.team({ required: true }) };
    test('has an team', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield TeamCommand.mock(['--team', 'myteam']);
        expect(teamfn).toBeCalledWith('myteam');
    }));
    test('-t', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield TeamCommand.mock(['-t', 'myteam']);
        expect(teamfn).toBeCalledWith('myteam');
    }));
    test('errors with no team', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        expect.assertions(1);
        try {
            yield TeamCommand.mock();
        }
        catch (err) {
            expect(err.message).toContain('Missing required flag:\n -t, --team TEAM');
        }
    }));
});
describe('optional', () => {
    class TeamCommand extends command_1.Command {
        run() {
            return tslib_1.__awaiter(this, void 0, void 0, function* () {
                teamfn(this.flags.team);
            });
        }
    }
    TeamCommand.flags = { team: flags.team() };
    test('--team', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield TeamCommand.mock(['--team', 'myteam']);
        expect(teamfn).toBeCalledWith('myteam');
    }));
    test('-t', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield TeamCommand.mock(['-t', 'myteam']);
        expect(teamfn).toBeCalledWith('myteam');
    }));
    test('reads HEROKU_ORGANIZATION as a backup', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        class TeamCommand extends command_1.Command {
            run() {
                return tslib_1.__awaiter(this, void 0, void 0, function* () {
                    teamfn(this.flags.team);
                });
            }
        }
        TeamCommand.flags = { team: flags.team() };
        process.env.HEROKU_ORGANIZATION = 'myenvteam';
        yield TeamCommand.mock();
        expect(teamfn).toBeCalledWith('myenvteam');
    }));
    test('reads --org as a backup', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        class TeamCommand extends command_1.Command {
            run() {
                return tslib_1.__awaiter(this, void 0, void 0, function* () {
                    teamfn(this.flags.team);
                });
            }
        }
        TeamCommand.flags = { team: flags.team({ required: true }), org: flags.org() };
        yield TeamCommand.mock(['--org', 'myteam']);
        expect(teamfn).toBeCalledWith('myteam');
    }));
    test('reads HEROKU_TEAM', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        class TeamCommand extends command_1.Command {
            run() {
                return tslib_1.__awaiter(this, void 0, void 0, function* () {
                    teamfn(this.flags.team);
                });
            }
        }
        TeamCommand.flags = { team: flags.team() };
        process.env.HEROKU_TEAM = 'myteam';
        yield TeamCommand.mock();
        expect(teamfn).toBeCalledWith('myteam');
    }));
    test('does not error when team is not specified', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield TeamCommand.mock();
    }));
});
