"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vars_1 = require("./vars");
let env = process.env;
beforeEach(() => {
    process.env = {};
});
afterEach(() => {
    process.env = env;
});
jest.mock('netrc-parser', () => {
    return class {
        constructor() {
            this.machines = { 'api.heroku.com': { password: 'mypass' } };
        }
    };
});
test('sets vars by default', () => {
    expect(vars_1.vars.host).toEqual('heroku.com');
    expect(vars_1.vars.apiHost).toEqual('api.heroku.com');
    expect(vars_1.vars.gitHost).toEqual('heroku.com');
    expect(vars_1.vars.apiUrl).toEqual('https://api.heroku.com');
    expect(vars_1.vars.gitHost).toEqual('heroku.com');
    expect(vars_1.vars.httpGitHost).toEqual('git.heroku.com');
    expect(vars_1.vars.gitPrefixes).toEqual(['git@heroku.com:', 'ssh://git@heroku.com/', 'https://git.heroku.com/']);
});
test('respects HEROKU_HOST', () => {
    process.env.HEROKU_HOST = 'customhost';
    expect(vars_1.vars.apiHost).toEqual('api.customhost');
    expect(vars_1.vars.apiUrl).toEqual('https://api.customhost');
    expect(vars_1.vars.gitHost).toEqual('customhost');
    expect(vars_1.vars.host).toEqual('customhost');
    expect(vars_1.vars.httpGitHost).toEqual('git.customhost');
    expect(vars_1.vars.gitPrefixes).toEqual(['git@customhost:', 'ssh://git@customhost/', 'https://git.customhost/']);
});
test('respects HEROKU_HOST as url', () => {
    process.env.HEROKU_HOST = 'https://customhost';
    expect(vars_1.vars.host).toEqual('https://customhost');
    expect(vars_1.vars.apiHost).toEqual('customhost');
    expect(vars_1.vars.apiUrl).toEqual('https://customhost');
    expect(vars_1.vars.gitHost).toEqual('customhost');
    expect(vars_1.vars.httpGitHost).toEqual('customhost');
    expect(vars_1.vars.gitPrefixes).toEqual(['git@customhost:', 'ssh://git@customhost/', 'https://customhost/']);
});
